@@ -1,5 +1,3 @@
-# $Id$
-
 package WebService::Simple;
 use strict;
 use warnings;
@@ -11,7 +9,7 @@ use URI::Escape;
 use WebService::Simple::Response;
 use UNIVERSAL::require;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 __PACKAGE__->config(
     base_url        => '',
@@ -173,7 +171,19 @@ sub get {
 }
 
 sub post {
-    my ( $self, $url, @params ) = @_;
+    my $self = shift;
+    my ( $url, %extra );
+
+    if ( ref $_[0] eq 'HASH' ) {
+        $url   = "";
+        %extra = %{ shift @_ };
+    }
+    else {
+        $url = shift @_;
+        if ( ref $_[0] eq 'HASH' ) {
+            %extra = %{ shift @_ };
+        }
+    }
 
     # XXX - do not include params
     my $uri = $self->request_url(
@@ -181,10 +191,9 @@ sub post {
         extra_path => $url
     );
 
-    # default parameters must come *before* @params, so unshift instead
-    # of push
-    unshift @params, %{ $self->basic_params };
-    my $response = $self->SUPER::post( $uri, @params );
+    my @headers = @_;
+    
+    my $response = $self->SUPER::post( $uri, { %{ $self->basic_params }, %extra }, @headers );
 
     if ( !$response->is_success ) {
         Carp::croak( "request to $url failed: " . $response->status_line );
@@ -367,6 +376,8 @@ Daisuke Maki C<< <daisuke@endeworks.jp> >>
 
 Matsuno Tokuhiro
 
+Naoki Tomita (tomi-ru)
+
 =head1 COPYRIGHT AND LICENSE
 
 This module is free software; you can redistribute it
